==> linuxconf-1.17.src.tar.gz: linuxconf-1.17/diajava/proto.java <==
// created by proto.sh from proto.lst
class proto {
public static final int Str = 1;
public static final int Newline = 2;
public static final int Skip = 3;
public static final int Hline = 4;
public static final int Dispolast = 5;
public static final int Label = 6;
public static final int String = 7;
public static final int Checkbox = 8;
public static final int Radio = 9;
public static final int Button = 10;
public static final int Button_xpm = 11;
public static final int Button_xpmf = 12;
public static final int Choice = 13;
public static final int Choice_item = 14;
public static final int List = 15;
public static final int List_item = 16;
public static final int Combo = 17;
public static final int Combo_item = 18;
public static final int Group = 19;
public static final int Form = 20;
public static final int Page = 21;
public static final int Book = 22;
public static final int MainForm = 23;
public static final int End = 24;
public static final int Delete = 25;
public static final int Dump = 26;
public static final int Icon_xpm = 27;
public static final int Xfer_xpm = 28;
public static final int Sidetitle = 29;
public static final int Fill = 30;
public static final int Formbutton = 31;
public static final int Groupfit = 32;
public static final int Setweightlast = 33;
public static final int Richtext = 34;
public static final int Password = 35;
public static final int Buttonfill = 36;
public static final int Enteraction = 37;
public static final int Curfield = 38;
public static final int Version = 39;
public static final int Treemenu = 40;
public static final int Treeelem = 41;
public static final int Clist = 42;
public static final int Clist_item = 43;
public static final int Html = 44;
public static final int Treesub = 45;
public static final int Sheet = 46;
public static final int Sheet_item = 47;
public static final int Textarea = 48;
public static final int Slider = 49;
public static final int Gauge = 50;
public static final int Setval = 51;
public static final int Alive = 52;
public static final int Setcontext = 53;
public static final int last = 53;
}

==> linuxconf-1.18.src.tar.gz: linuxconf-1.18/diajava/proto.java <==
// created by proto.sh from proto.lst
class proto {
public static final int Str = 1;
public static final int Newline = 2;
public static final int Skip = 3;
public static final int Hline = 4;
public static final int Dispolast = 5;
public static final int Label = 6;
public static final int String = 7;
public static final int Checkbox = 8;
public static final int Radio = 9;
public static final int Button = 10;
public static final int Button_xpm = 11;
public static final int Button_xpmf = 12;
public static final int Choice = 13;
public static final int Choice_item = 14;
public static final int List = 15;
public static final int List_item = 16;
public static final int Combo = 17;
public static final int Combo_item = 18;
public static final int Group = 19;
public static final int Form = 20;
public static final int Page = 21;
public static final int Book = 22;
public static final int MainForm = 23;
public static final int End = 24;
public static final int Delete = 25;
public static final int Dump = 26;
public static final int Icon_xpm = 27;
public static final int Xfer_xpm = 28;
public static final int Sidetitle = 29;
public static final int Fill = 30;
public static final int Formbutton = 31;
public static final int Groupfit = 32;
public static final int Setweightlast = 33;
public static final int Richtext = 34;
public static final int Password = 35;
public static final int Buttonfill = 36;
public static final int Enteraction = 37;
public static final int Curfield = 38;
public static final int Version = 39;
public static final int Treemenu = 40;
public static final int Treeelem = 41;
public static final int Clist = 42;
public static final int Clist_item = 43;
public static final int Html = 44;
public static final int Treesub = 45;
public static final int Sheet = 46;
public static final int Sheet_item = 47;
public static final int Textarea = 48;
public static final int Slider = 49;
public static final int Gauge = 50;
public static final int Setval = 51;
public static final int Alive = 52;
public static final int Setcontext = 53;
public static final int Defdc = 54;
public static final int Deffont = 55;
public static final int Defpen = 56;
public static final int Defbrush = 57;
public static final int Drawline = 58;
public static final int Drawrect = 59;
public static final int Drawarc = 60;
public static final int Fillrect = 61;
public static final int Fillarc = 62;
public static final int Menubar = 63;
public static final int Popupmenu = 64;
public static final int Submenu = 65;
public static final int Menuentry = 66;
public static final int Clear = 67;
public static final int Drawclip = 68;
public static final int Setcursor = 69;
public static final int Blit = 70;
public static final int Drawtext = 71;
public static final int last = 71;
}
